@@ -9,10 +9,21 @@ from tkinter import messagebox
 
 import qgui
 
+# 资源部分
 QGUI_BASE_PATH = os.path.dirname(qgui.__file__)
 RESOURCES_PATH = os.path.join(QGUI_BASE_PATH, "resources")
 ICON_PATH = os.path.join(RESOURCES_PATH, "icon")
 
+HORIZONTAL = "Horizontal水平方向"
+VERTICAL = "Vertical垂直方向"
+
+
+# Tools部分
+class ConcurrencyModeFlag:
+    # QUEUE_ = "触发后相关事件会以队列的形式执行"
+    SAFE_CONCURRENCY_MODE_FLAG = "不允许并发，禁止触发下一个事件"
+    # FORCE_CONCURRENCY_MODE_FLAG = "不允许并发，下一个事件被触发时结束上一个事件"
+
 
 class QStyle:
     default = None
@@ -35,4 +46,7 @@ class MessageBox:
         messagebox.showerror(title, text)
 
 
-
+BLACK = "#24262d"
+GRAY = "#e3e3e3"
+GREEN = "#76b67e"
+FONT = "黑体"
